@@ -160,13 +160,14 @@ class XSQLibrary(h5py._hl.group.Group):
     def iter_colourqual(self, fragment):
         """ 
         Iterator over the sequence reads for the fragment 'fragment'.
-        Each iteration returns a tuple of length 2:
+        Each iteration returns a named tuple of length 2:
 
-        - the colour sequence
+        - colour: the sequence of colours
 
-        - the quality
+        - qual: the quality for the sequence
 
-        For a naive colour-to-sequence translation, the first base for the fragment
+        For a naive colour-to-sequence translation,
+        the first base for the fragment
         should be used. It is in the dict FRAGMENT_START.
         """
         for read in self.iter_reads(fragment, what='ColorCallQV'):
@@ -199,6 +200,7 @@ def _read_values(group, fragment, what):
         yield ds
 
 def tile_valuearray(tile, fragment, what):
+    """ Get the array of values for a tile. """
     if fragment not in tile:
         raise FragmentError('No such fragment "%s"' %fragment)
     ds = tile[fragment][what].value
@@ -600,7 +602,7 @@ def make_htmlreport(xsqfile, directory = '.', verbose = True,
     LibReport = namedtuple("LibReport", 
                            "name lib_i readcount fragments")
     FragmentReport = namedtuple("FragmentReport",
-                                "name data_fn")
+                                "name varname data_fn")
     libs = list()
     for lib_i, lib in enumerate(xsqfile.iter_lib()):
         if verbose:
@@ -608,11 +610,12 @@ def make_htmlreport(xsqfile, directory = '.', verbose = True,
             sys.stdout.flush()
         frags = list()
         for fragment in lib.fragments():
+            frg_varname = fragment.replace('-', '')
             #FIXME: only consider colour space for now
             fq = fastqual(lib, fragment, 'ColorCallQV', sample = sample_percent)
             # build the CSV file with quality
             data_fn = os.path.join(directory, 
-                                  'fastqual_%s_%s_%i.%s' % (lib.name, fragment, lib_i, data_type))
+                                  'fastqual_%s_%s_%i.%s' % (lib.name, frg_varname, lib_i, data_type))
             if verbose:
                 sys.stdout.write('Creating file %s...' % data_fn)
             f = file(data_fn, mode = 'w')
@@ -623,13 +626,13 @@ def make_htmlreport(xsqfile, directory = '.', verbose = True,
             else:
                 # json
                 tmp = report.fastqual_tojson(fq)
-                f.write('dataf_%i_%s = ' % (lib_i, fragment) )
+                f.write('dataf_%i_%s = ' % (lib_i, frg_varname) )
                 f.write(tmp)
                 f.write(';')
             f.close()
             if verbose:
                 sys.stdout.write('done.\n')
-            frags.append(FragmentReport(fragment, os.path.relpath(data_fn, start = directory)))
+            frags.append(FragmentReport(fragment, frg_varname, os.path.relpath(data_fn, start = directory)))
         libs.append(LibReport(lib.name, lib_i, 
                               lib.readcount(), frags))
             
