@@ -173,7 +173,12 @@ def htmlreport():
         print('XSQ files are expected to have the extension XSQ.')
         sys.exit(1)
     dest_dir = os.path.join(options.dest_dir, xsq_fn[:sep_i])
-
+    try:
+        os.mkdir(dest_dir)
+    except:
+        sys.stderr.write('Could not create directory %s\n' % dest_dir)
+        sys.stderr.flush()
+        sys.exit(1)
     if os.path.exists(options.dest_dir):
         if not os.path.isdir(options.dest_dir):
             print('Error: destination directory already existing (but not as a directory')
